@@ -53,12 +53,17 @@ class DOMHTMLSearchMovieParser(DOMParserBase):
                     Rule(
                         key='akas',
                         extractor=Path(foreach='./i', path='./text()')
+                    ),
+                    Rule(
+                        key='cover url',
+                        extractor=Path('../td[@class="primary_photo"]/a/img/@src')
                     )
                 ],
                 transform=lambda x: (
                     analyze_imdbid(x.get('link')),
                     analyze_title(x.get('info', '')),
-                    x.get('akas')
+                    x.get('akas'),
+                    x.get('cover url')
                 )
             )
         )
@@ -66,6 +71,7 @@ class DOMHTMLSearchMovieParser(DOMParserBase):
 
     def _init(self):
         self.url = ''
+        self.img_type = 'cover url'
 
     def _reset(self):
         self.url = ''
@@ -78,7 +84,7 @@ class DOMHTMLSearchMovieParser(DOMParserBase):
             data['data'][:] = data['data'][:results]
         # Horrible hack to support AKAs.
             data['data'] = [x for x in data['data'] if x[0] and x[1]]
-        if data and data['data'] and len(data['data'][0]) == 3 and isinstance(data['data'][0], tuple):
+        if data and data['data'] and len(data['data'][0]) == 4 and isinstance(data['data'][0], tuple):
             for idx, datum in enumerate(data['data']):
                 if not isinstance(datum, tuple):
                     continue
@@ -87,9 +93,9 @@ class DOMHTMLSearchMovieParser(DOMParserBase):
                 if datum[2] is not None:
                     akas = [aka[1:-1] for aka in datum[2]]  # remove the quotes
                     datum[1]['akas'] = akas
-                    data['data'][idx] = (datum[0], datum[1])
-                else:
-                    data['data'][idx] = (datum[0], datum[1])
+                if datum[3] is not None:
+                    datum[1][self.img_type] = datum[3]
+                data['data'][idx] = (datum[0], datum[1])
         return data
 
     def add_refs(self, data):
